import React, {Fragment} from "react";
import App, {Container as NextContainer} from "next/app";
import {Col, Layout, Menu, Row} from "antd";
import stylesheet from 'antd/dist/antd.min.css'
import Link from "next/link";
import styled from "styled-components";
import Icon from "antd/lib/icon";
import {withRouter} from "next/router";
import Dropdown from "antd/lib/dropdown";

const {Header, Content, Sider} = Layout;

class MyApp extends App {
  static async getInitialProps({Component, ctx}) {
    let pageProps = {};
    if (Component.getInitialProps) {
      pageProps = await Component.getInitialProps(ctx);
    }
    if (ctx.req && ctx.req.session.passport) {
      pageProps.user = ctx.req.session.passport.user;
    }
    return {pageProps};
  }

  constructor(props) {
    super(props);
    this.state = {
      user: props.pageProps.user
    };
  }

  render() {
    const {Component, pageProps, router} = this.props;

    let user = this.state.user;
    const props = {
      ...pageProps,
      user: user,
    };
    let currentMainMenu = router.asPath.split('/')[1];
    const menu = (
      <Menu>
        <Menu.Item>
          <Link href="/logout">
            <a>Log out</a>
          </Link>
        </Menu.Item>
      </Menu>
    );
    return (
      <NextContainer>
        <style dangerouslySetInnerHTML={{__html: stylesheet}}/>
        <Layout>
          <Header className="header" style={{paddingRight: "20px"}}>
            <Row type="flex" justify="space-between">
              <Col span={4}>
                <div className="logo">
                  <Link href="/">
                    <a style={{fontSize: "25px"}}>Jean Grey</a>
                  </Link>
                </div>
              </Col>
              <Col span={4}>
                {user &&
                <Fragment>
                  <Dropdown overlay={menu} placement="bottomCenter">
                    <div style={{color: "#fff", float: "right"}}>
                      <img style={{
                        borderRadius: "50%",
                        border: "3px solid white",
                        width: "30px"
                      }} src={user.picture} alt={user.displayName}/> &nbsp; Hello, {user.displayName} &nbsp;
                      <Icon type="caret-down"/>
                    </div>
                  </Dropdown>
                </Fragment>
                }
              </Col>
            </Row>
          </Header>
          <Layout>
            <Sider theme={"dark"}>
              <Menu
                theme={"dark"}
                mode="vertical-left"
                selectedKeys={[currentMainMenu]}
              >
                <Menu.Item key="dictionary">
                  <Link href="/dictionary">
                    <a><Icon type="unordered-list"/> Dictionary</a>
                  </Link>
                </Menu.Item>
              </Menu>
            </Sider>
            <Content style={{background: '#fff', padding: 15, minHeight: "90vh"}}>
              <Component {...props} />
            </Content>
          </Layout>
        </Layout>

      </NextContainer>
    );
  }
}

export default withRouter(MyApp);

