import {Button, Icon, Input, PageHeader, Table} from 'antd';
import {Fragment, default as React} from "react";
// import {useRouter} from 'next/router';
import _ from 'lodash';
import Row from "antd/lib/grid/row";
import Col from "antd/lib/grid/col";
import styled from "styled-components";
import Text from "antd/lib/typography/Text";
import {withRouter} from 'next/router';
import Popconfirm from "antd/lib/popconfirm";

class Dictionary extends React.Component {
  constructor(props) {
    super(props);
    const self = this;
    let {indexes, router} = props;
    const {dict_id} = router.query;
    const current_dict = _.filter(indexes, dict => dict.id === parseInt(dict_id))[0];
    const current_dict_map = _.map(current_dict.words, item => ({
      word: item,
      key: item,
    }));
    this.state = {
      fullTableData: current_dict_map,
      filteredTableData: current_dict_map,
      current_dict: current_dict
    };
  }

  render() {
    const cols = [
      {
        title: "Word",
        dataIndex: "word",
        sorter: (a, b) => a.word.localeCompare(b.word),
        defaultSortOrder: ['ascend'],
      },
      {
        title: "Action",
        render: (text, record) => (<Fragment>
          <Button><Icon type="edit" theme={"twoTone"}/></Button> &nbsp;
          <Button>
            <Popconfirm title={<span>Are you sure to delete word  <Text code>{record.word}</Text>?</span>}
                        okText="Delete"
                        onConfirm={() => this.handleDelete(record.key)}>
              <a href="javascript:;"><Icon type="delete" theme={"twoTone"}/></a>
            </Popconfirm>
          </Button>
        </Fragment>),
        width: '15%',
      },
    ];

    return (
      <Fragment>
        <PageHeader title={<Fragment>Dictionary <Text> {this.state.current_dict.name} </Text></Fragment>}/>
        <Row gutter={24} style={{marginBottom: '15px'}}>
          <Col xs={24} sm={24} md={12} lg={8} xl={6}>
            <Input style={{marginLeft: '15px'}} className={"searchInput"}
                   prefix={<Icon type="filter" allowClear theme={"twoTone"}/>} onChange={this.onSearchChange}
              // value={this.state.searchKeyword}
                   placeholder={"Filter by word"}/>
          </Col>
          <Col style={{float: "right", justifyContent: "right"}} xs={24} sm={24} md={12} lg={{span: 8}} xl={6}>
            <Button icon={"plus"} type={"primary"} style={{float: "right", marginRight: "15px"}}> Add word
            </Button>
          </Col>
        </Row>
        <Table dataSource={this.state.filteredTableData} columns={cols}>
        </Table>

      </Fragment>
    );
  }

  onSearchChange = (e) => {
    let searchString = e.target.value;
    let fullTableData = this.state.fullTableData;
    let filteredData = _.filter(fullTableData, item => item.word.toLowerCase().indexOf(searchString) >= 0);
    this.setState({
      filteredTableData: filteredData,
      searchString: searchString
    });
  };

  handleDelete(key) {
    let afterDeletedData = this.state.fullTableData.filter(item => item.key !== key);
    let searchString = this.state.searchString;
    let afterDeletedFilteredData = _.filter(afterDeletedData, item => item.word.toLowerCase().indexOf(searchString) >= 0);
    this.setState({
      fullTableData: afterDeletedData,
      filteredTableData: afterDeletedFilteredData,
    });
  }
}


Dictionary.getInitialProps = async ({req}) => {
  let indexes = [
    {
      id: 1,
      name: "black",
      type: "blacklist",
      words: [
        'fuck',
        "2g1c",
        "2 girls 1 cup",
        "anal",
        "anus",
        "arse",
        "ass",
      ]
    },
    {
      id: 2,
      name: 'ip',
      type: "blacklist",
      words: [
        '102.232.434.545'
      ]
    }
  ];

  return {indexes};
};

export default withRouter(Dictionary);
