require("dotenv").config();
const express = require("express");
const http = require("http");
const next = require("next");
const session = require("express-session");
const passport = require("passport");
const Auth0Strategy = require("passport-auth0");
const uid = require('uid-safe');
const authRoutes = require("./auth-routes");

const _ = require('lodash');
const dev = process.env.NODE_ENV !== "production";
const app = next({
  dev: true,
  dir: "./src"
});
const handle = app.getRequestHandler();

app.prepare().then(() => {
  const server = express();

  const sessionConfig = {
    secret: uid.sync(18),
    cookie: {
      maxAge: 86400 * 1000 // 24 hours in milliseconds
    },
    resave: false,
    saveUninitialized: true
  };
  server.use(session(sessionConfig));

  const auth0Strategy = new Auth0Strategy(
    {
      // domain: process.env.AUTH0_DOMAIN,
      // clientID: process.env.AUTH0_CLIENT_ID,
      // clientSecret: process.env.AUTH0_CLIENT_SECRET,
      // callbackURL: process.env.AUTH0_CALLBACK_URL
      domain: "adperfect-admin.auth0.com",
      clientID: "gH6CTesvUxakYwCoFjAwmEIqR7d0e1iy",
      clientSecret: "lLPLu7YGogeidcO1felX0He9CCGJx2PZ9e5643ULOSjH7jXG_sHjSoZBr43VIr9n",
      callbackURL: "http://localhost:3000/callback"
    },
    function (accessToken, refreshToken, extraParams, profile, done) {
      const allowedEmail = ["bob.bui@adperfect.com"];
      let anies = _.intersection(_.map(profile.emails, item => item.value), allowedEmail);
      if (!_.isEmpty(anies)) {
        return done(null, profile);
      }

      return done(null, null, 'Un-authorized domain or no permission');
    }
  );

  passport.use(auth0Strategy);
  passport.serializeUser((user, done) => {
    return done(null, user);
  });
  passport.deserializeUser((user, done) => {
    return done(null, user);
  });

  // 5 - adding Passport and authentication routes
  server.use(passport.initialize());
  server.use(passport.session());
  server.use(authRoutes);

  const unprotectedRoutes = [];

  const restrictAccess = (req, res, next) => {
    if (!req.isAuthenticated() && !_.includes(unprotectedRoutes, req.path))
      return res.redirect("/login");

    next();
  };

  server.get("*", restrictAccess, handle);

  http.createServer(server).listen(3000, () => {
    console.log(`listening on port ${3000}`);
  });
});
